==> Tekkotsu_2.2.1.tar.gz: Tekkotsu_2.2.1/Events/EventBase.cc <==
#include "EventBase.h"
#include <stdio.h>
#include <sstream>

const char* const EventBase::EventGeneratorNames[numEGIDs] = {
	"unknownEGID",
	"aiEGID",
	"audioEGID",
	"buttonEGID",
	"erouterEGID",
	"estopEGID",
	"locomotionEGID",
	"micOSndEGID",
	"micRawEGID",
	"micFFTEGID",
	"motmanEGID",
	"powerEGID",
	"sensorEGID",
	"stateMachineEGID",
	"testmsgEGID",
	"timerEGID",
	"visOFbkEGID",
	"visRawCameraEGID",
	"visInterleaveEGID",
	"visJPEGEGID",
	"visSegmentEGID",
	"visRLEEGID",
	"visRegionEGID",
	"visObjEGID",
	"wmVarEGID",
	"worldModelEGID",
};


EventBase::EventBase()
	: LoadSave(), stim_id(), magnitude(0), timestamp(get_time()), nameisgen(true), genID(unknownEGID), typeID(statusETID), sourceID((unsigned int)-1), duration(0)
{
	genName();
}

EventBase::EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur)
	: LoadSave(), stim_id(), magnitude(0), timestamp(get_time()), nameisgen(true), genID(gid), typeID(tid), sourceID(sid), duration(dur)
{
	genName();
	if(tid==deactivateETID)
		setMagnitude(0.0);
	else
		setMagnitude(1.0);
}

EventBase::EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur, const std::string& n, float mag)
	: LoadSave(), stim_id(n), magnitude(mag), timestamp(get_time()), nameisgen(false), genID(gid), typeID(tid), sourceID(sid), duration(dur)
{
	
}

std::string
EventBase::getDescription(bool /*showTypeSpecific=true*/, unsigned int verbosity/*=0*/) const {
	std::ostringstream logdata;
	logdata << getName();
	char hexstring[30];
	snprintf(hexstring,sizeof(hexstring),"0x%x",getSourceID());
	logdata << '\t' << hexstring;
	switch(getTypeID()) {
	case EventBase::activateETID:
		logdata << "\tA"; break;
	case EventBase::statusETID:
		logdata << "\tS"; break;
	case EventBase::deactivateETID:
		logdata << "\tD"; break;
	case EventBase::numETIDs:
		logdata << "\tU"; break;  //UNKNOWN TYPE
	}
	if(verbosity>=1)
		logdata << '\t' << getDuration() << '\t' << getTimeStamp();
	if(verbosity>=2)
		logdata << '\t' << getMagnitude();
	return logdata.str();
}

unsigned int
EventBase::getBinSize() const {
	unsigned int used=0;
	used+=creatorSize("EventBase");
	used+=stim_id.size()+stringpad;
	used+=sizeof(magnitude);
	used+=sizeof(timestamp);
	used+=sizeof(nameisgen);
	used+=sizeof(char);
	used+=sizeof(char);
	used+=sizeof(sourceID);
	used+=sizeof(duration);
	return used;
}

unsigned int
EventBase::LoadBuffer(const char buf[], unsigned int len) {
	unsigned int origlen=len;
	unsigned int used=0;
	if(0==(used=checkCreator("EventBase",buf,len,true))) return 0;
	len-=used; buf+=used;
	if(0==(used=decode(stim_id,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=decode(magnitude,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=decode(timestamp,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=decode(nameisgen,buf,len))) return 0;
	len-=used; buf+=used;
	char tmp;
	if(0==(used=decode(tmp,buf,len))) return 0;
	genID=(EventGeneratorID_t)tmp;
	len-=used; buf+=used;
	if(0==(used=decode(tmp,buf,len))) return 0;
	typeID=(EventTypeID_t)tmp;
	len-=used; buf+=used;
	if(0==(used=decode(sourceID,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=decode(duration,buf,len))) return 0;
	len-=used; buf+=used;
	return origlen-len;	
}

unsigned int
EventBase::SaveBuffer(char buf[], unsigned int len) const {
	unsigned int origlen=len;
	unsigned int used=0;
	if(0==(used=saveCreator("EventBase",buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode(stim_id,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode(magnitude,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode(timestamp,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode(nameisgen,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode((char)genID,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode((char)typeID,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode(sourceID,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode(duration,buf,len))) return 0;
	len-=used; buf+=used;
	return origlen-len;
}

void
EventBase::genName() {
	if(!nameisgen)
		return;
	if(genID<numEGIDs) {
		stim_id=std::string("Evt_");
		stim_id+=EventGeneratorNames[genID];
	} else {
		stim_id=std::string("Evt_InvalidGen");
		stim_id+=genID; 
	}
	stim_id+="::";
	char tmp[16];
	snprintf(tmp,16,"0x%x",sourceID);
	stim_id+=tmp;
}

/*! @file
 * @brief Implements EventBase, the basic class for sending events around the system
 * @author ejt (Creator)
 *
 * $Author: ejt $
 * $Name: tekkotsu-2_2_1 $
 * $Revision: 1.19 $
 * $State: Exp $
 * $Date: 2004/09/28 23:07:02 $
 */

==> Tekkotsu_2.2.2.tar.gz: Tekkotsu_2.2.2/Events/EventBase.cc <==
#include "EventBase.h"
#include <stdio.h>
#include <sstream>

const char* const EventBase::EventGeneratorNames[numEGIDs] = {
	"unknownEGID",
	"aiEGID",
	"audioEGID",
	"buttonEGID",
	"erouterEGID",
	"estopEGID",
	"locomotionEGID",
	"micOSndEGID",
	"micRawEGID",
	"micFFTEGID",
	"motmanEGID",
	"powerEGID",
	"sensorEGID",
	"stateMachineEGID",
	"stateTransitionEGID",
	"testmsgEGID",
	"timerEGID",
	"visOFbkEGID",
	"visRawCameraEGID",
	"visInterleaveEGID",
	"visJPEGEGID",
	"visSegmentEGID",
	"visRLEEGID",
	"visRegionEGID",
	"visObjEGID",
	"wmVarEGID",
	"worldModelEGID",
};


EventBase::EventBase()
	: LoadSave(), stim_id(), magnitude(0), timestamp(get_time()), nameisgen(true), genID(unknownEGID), typeID(statusETID), sourceID((unsigned int)-1), duration(0)
{
	genName();
}

EventBase::EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur)
	: LoadSave(), stim_id(), magnitude(0), timestamp(get_time()), nameisgen(true), genID(gid), typeID(tid), sourceID(sid), duration(dur)
{
	genName();
	if(tid==deactivateETID)
		setMagnitude(0.0);
	else
		setMagnitude(1.0);
}

EventBase::EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur, const std::string& n, float mag)
	: LoadSave(), stim_id(), magnitude(mag), timestamp(get_time()), nameisgen(true), genID(gid), typeID(tid), sourceID(sid), duration(dur)
{
	setName(n);
}

EventBase&
EventBase::setName(const std::string& sourcename) {
	stim_id='(';
	if(genID<numEGIDs) {
		stim_id+=EventGeneratorNames[genID];
	} else {
		stim_id+=std::string("InvalidGen");
		char tmp2[16];
		snprintf(tmp2,16,"(%d)",genID);
		stim_id+=tmp2; 
	}
	stim_id+=',';
	stim_id+=sourcename;
	stim_id+=',';
	switch(getTypeID()) {
	case EventBase::activateETID:
		stim_id+='A'; break;
	case EventBase::statusETID:
		stim_id+='S'; break;
	case EventBase::deactivateETID:
		stim_id+='D'; break;
	default:
		stim_id+='U'; break; //unknown
	}
	stim_id+=')';
	nameisgen=false;
	return *this;
}

std::string
EventBase::getDescription(bool /*showTypeSpecific=true*/, unsigned int verbosity/*=0*/) const {
	std::ostringstream logdata;
	logdata << getName();
	if(verbosity>=1)
		logdata << '\t' << getGeneratorID() << '\t' << getSourceID() << '\t' << getTypeID();
	if(verbosity>=2)
		logdata << '\t' << getDuration() << '\t' << getTimeStamp();
	if(verbosity>=3)
		logdata << '\t' << getMagnitude();
	return logdata.str();
}

unsigned int
EventBase::getBinSize() const {
	unsigned int used=0;
	used+=creatorSize("EventBase");
	used+=stim_id.size()+stringpad;
	used+=sizeof(magnitude);
	used+=sizeof(timestamp);
	used+=sizeof(nameisgen);
	used+=sizeof(char);
	used+=sizeof(char);
	used+=sizeof(sourceID);
	used+=sizeof(duration);
	return used;
}

unsigned int
EventBase::LoadBuffer(const char buf[], unsigned int len) {
	unsigned int origlen=len;
	unsigned int used=0;
	if(0==(used=checkCreator("EventBase",buf,len,true))) return 0;
	len-=used; buf+=used;
	if(0==(used=decode(stim_id,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=decode(magnitude,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=decode(timestamp,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=decode(nameisgen,buf,len))) return 0;
	len-=used; buf+=used;
	char tmp;
	if(0==(used=decode(tmp,buf,len))) return 0;
	genID=(EventGeneratorID_t)tmp;
	len-=used; buf+=used;
	if(0==(used=decode(tmp,buf,len))) return 0;
	typeID=(EventTypeID_t)tmp;
	len-=used; buf+=used;
	if(0==(used=decode(sourceID,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=decode(duration,buf,len))) return 0;
	len-=used; buf+=used;
	return origlen-len;	
}

unsigned int
EventBase::SaveBuffer(char buf[], unsigned int len) const {
	unsigned int origlen=len;
	unsigned int used=0;
	if(0==(used=saveCreator("EventBase",buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode(stim_id,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode(magnitude,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode(timestamp,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode(nameisgen,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode((char)genID,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode((char)typeID,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode(sourceID,buf,len))) return 0;
	len-=used; buf+=used;
	if(0==(used=encode(duration,buf,len))) return 0;
	len-=used; buf+=used;
	return origlen-len;
}

void
EventBase::genName() {
	if(!nameisgen)
		return;
	char tmp[16];
	snprintf(tmp,16,"%d",sourceID);
	setName(tmp);
	nameisgen=true;
}

/*! @file
 * @brief Implements EventBase, the basic class for sending events around the system
 * @author ejt (Creator)
 *
 * $Author: ejt $
 * $Name: tekkotsu-2_2_2 $
 * $Revision: 1.24 $
 * $State: Exp $
 * $Date: 2004/12/22 23:54:07 $
 */
